@@ -1,4 +1,5 @@
 library(circlize)
+op = par(no.readonly = FALSE)
 par(mar = c(1, 1, 1, 1), mfrow = c(1, 2))
 fa = c("d", "f", "e", "c", "g", "b", "a")
 f1 = factor(fa)
@@ -14,3 +15,4 @@ circos.trackPlotRegion(ylim = c(0, 1))
 show.index()
 text(0, 0, "factor(fa,\nlevels = fa)", adj = c(0.5, 0.5), cex = 1.3)
 circos.clear()
+par(op)
