@@ -1,4 +1,5 @@
 library(circlize)
+op = par(no.readonly = FALSE)
 par(mar = c(1, 1, 1, 1))
 factors = letters[1:4]
 circos.initialize(factors, xlim = c(0, 1))
@@ -16,4 +17,5 @@ circos.trackPlotRegion(ylim = c(-3, 3), track.height = 0.4, panel.fun = function
     circos.points(x1, y1, cex = 0.5)
     circos.lines(x1, loess.predict$fit)
 })
-circos.clear()
\ No newline at end of file
+circos.clear()
+par(op)
